@@ -25,16 +25,7 @@ sudo rm -rf dist
 mkdir dist
 
 echo "Install pyinstaller and build bootloaders for M1"
-#pip install pyinstaller==4.3
-# Once there is a 4.4, we can clone that tag and build that
-# M1 support isn't in a tag yet.
-# Alternatively, if the m1 bootloaders are distributed with pip in the future, can just use those
-git clone https://github.com/pyinstaller/pyinstaller.git
-cd pyinstaller/bootloader
-git checkout ab81fe39b11bc12216f86e85fb899ff13379c069
-python ./waf all
-pip install ..
-cd ../..
+pip install pyinstaller==4.5
 
 echo "Create executables with pyinstaller"
 SPEC_FILE=$(python -c 'import chia; print(chia.PYINSTALLER_SPEC_PATH)')
