@@ -1,4 +1,5 @@
 import click
+from chia.util.keychain import supports_keyring_passphrase
 
 
 @click.command("init", short_help="Create or migrate the configuration")
@@ -9,8 +10,14 @@ import click
     help="Create new SSL certificates based on CA in [directory]",
     type=click.Path(),
 )
+@click.option(
+    "--fix-ssl-permissions",
+    is_flag=True,
+    help="Attempt to fix SSL certificate/key file permissions",
+)
+@click.option("--set-passphrase", "-s", is_flag=True, help="Protect your keyring with a passphrase")
 @click.pass_context
-def init_cmd(ctx: click.Context, create_certs: str):
+def init_cmd(ctx: click.Context, create_certs: str, fix_ssl_permissions: bool, **kwargs):
     """
     Create a new configuration or migrate from previous versions to current
 
@@ -25,8 +32,20 @@ def init_cmd(ctx: click.Context, create_certs: str):
     """
     from pathlib import Path
     from .init_funcs import init
+    from chia.cmds.passphrase_funcs import initialize_passphrase
 
-    init(Path(create_certs) if create_certs is not None else None, ctx.obj["root_path"])
+    set_passphrase = kwargs.get("set_passphrase")
+    if set_passphrase:
+        initialize_passphrase()
+
+    init(Path(create_certs) if create_certs is not None else None, ctx.obj["root_path"], fix_ssl_permissions)
+
+
+if not supports_keyring_passphrase():
+    from chia.cmds.passphrase_funcs import remove_passphrase_options_from_cmd
+
+    # TODO: Remove once keyring passphrase management is rolled out to all platforms
+    remove_passphrase_options_from_cmd(init_cmd)
 
 
 if __name__ == "__main__":
