@@ -222,7 +222,7 @@ class FarmerAPI:
                         async with session.post(
                             f"{pool_url}/partial",
                             json=post_partial_request.to_json_dict(),
-                            ssl=ssl_context_for_root(get_mozilla_ca_crt()),
+                            ssl=ssl_context_for_root(get_mozilla_ca_crt(), log=self.farmer.log),
                         ) as resp:
                             if resp.ok:
                                 pool_response: Dict = json.loads(await resp.text())
