@@ -6,21 +6,21 @@ from clvm_tools import binutils
 
 from chia.full_node.generator import create_compressed_generator
 from chia.types.blockchain_format.program import SerializedProgram, Program
-from chia.types.coin_solution import CoinSolution
+from chia.types.coin_spend import CoinSpend
 from chia.types.generator_types import BlockGenerator, CompressorArg
 from chia.types.spend_bundle import SpendBundle
 from chia.util.byte_types import hexstr_to_bytes
 from chia.util.ints import uint32, uint64
 
 
-def spend_bundle_to_serialized_coin_solution_entry_list(bundle: SpendBundle) -> bytes:
+def spend_bundle_to_serialized_coin_spend_entry_list(bundle: SpendBundle) -> bytes:
     r = b""
-    for coin_solution in bundle.coin_solutions:
+    for coin_spend in bundle.coin_spends:
         r += b"\xff"
-        r += b"\xff" + SExp.to(coin_solution.coin.parent_coin_info).as_bin()
-        r += b"\xff" + bytes(coin_solution.puzzle_reveal)
-        r += b"\xff" + SExp.to(coin_solution.coin.amount).as_bin()
-        r += b"\xff" + bytes(coin_solution.solution)
+        r += b"\xff" + SExp.to(coin_spend.coin.parent_coin_info).as_bin()
+        r += b"\xff" + bytes(coin_spend.puzzle_reveal)
+        r += b"\xff" + SExp.to(coin_spend.coin.amount).as_bin()
+        r += b"\xff" + bytes(coin_spend.solution)
         r += b"\x80"
     r += b"\x80"
     return r
@@ -30,7 +30,7 @@ def simple_solution_generator(bundle: SpendBundle) -> BlockGenerator:
     """
     Simply quotes the solutions we know.
     """
-    cse_list = spend_bundle_to_serialized_coin_solution_entry_list(bundle)
+    cse_list = spend_bundle_to_serialized_coin_spend_entry_list(bundle)
     block_program = b"\xff"
 
     block_program += SExp.to(binutils.assemble("#q")).as_bin()
@@ -72,11 +72,11 @@ def compress_cse_puzzle(puzzle: SerializedProgram) -> Optional[bytes]:
     return match_standard_transaction_exactly_and_return_pubkey(puzzle)
 
 
-def compress_coin_solution(coin_solution: CoinSolution):
-    compressed_puzzle = compress_cse_puzzle(coin_solution.puzzle_reveal)
+def compress_coin_spend(coin_spend: CoinSpend):
+    compressed_puzzle = compress_cse_puzzle(coin_spend.puzzle_reveal)
     return [
-        [coin_solution.coin.parent_coin_info, coin_solution.coin.amount],
-        [compressed_puzzle, Program.from_bytes(bytes(coin_solution.solution))],
+        [coin_spend.coin.parent_coin_info, coin_spend.coin.amount],
+        [compressed_puzzle, Program.from_bytes(bytes(coin_spend.solution))],
     ]
 
 
@@ -86,20 +86,20 @@ def puzzle_suitable_for_compression(puzzle: SerializedProgram) -> bool:
 
 def bundle_suitable_for_compression(bundle: SpendBundle):
     ok = []
-    for coin_solution in bundle.coin_solutions:
-        ok.append(puzzle_suitable_for_compression(coin_solution.puzzle_reveal))
+    for coin_spend in bundle.coin_spends:
+        ok.append(puzzle_suitable_for_compression(coin_spend.puzzle_reveal))
     return all(ok)
 
 
-def compressed_coin_solution_entry_list(bundle: SpendBundle) -> List:
+def compressed_coin_spend_entry_list(bundle: SpendBundle) -> List:
     compressed_cse_list: List[List[Union[List[uint64], List[Union[bytes, None, Program]]]]] = []
-    for coin_solution in bundle.coin_solutions:
-        compressed_cse_list.append(compress_coin_solution(coin_solution))
+    for coin_spend in bundle.coin_spends:
+        compressed_cse_list.append(compress_coin_spend(coin_spend))
     return compressed_cse_list
 
 
 def compressed_spend_bundle_solution(original_generator_params: CompressorArg, bundle: SpendBundle) -> BlockGenerator:
-    compressed_cse_list = compressed_coin_solution_entry_list(bundle)
+    compressed_cse_list = compressed_coin_spend_entry_list(bundle)
     return create_compressed_generator(original_generator_params, compressed_cse_list)
 
 
