@@ -34,7 +34,7 @@ def service_kwargs_for_introducer(
     return kwargs
 
 
-def main():
+def main() -> None:
     config = load_config_cli(DEFAULT_ROOT_PATH, "config.yaml", SERVICE_NAME)
     kwargs = service_kwargs_for_introducer(DEFAULT_ROOT_PATH, config)
     return run_service(**kwargs)
