@@ -124,3 +124,29 @@ def str2bool(v: Union[str, bool]) -> bool:
         return False
     else:
         raise argparse.ArgumentTypeError("Boolean value expected.")
+
+
+def traverse_dict(d: Dict, key_path: str) -> Any:
+    """
+    Traverse nested dictionaries to find the element pointed-to by key_path.
+    Key path components are separated by a ':' e.g.
+      "root:child:a"
+    """
+    if type(d) is not dict:
+        raise TypeError(f"unable to traverse into non-dict value with key path: {key_path}")
+
+    # Extract one path component at a time
+    components = key_path.split(":", maxsplit=1)
+    if components is None or len(components) == 0:
+        raise KeyError(f"invalid config key path: {key_path}")
+
+    key = components[0]
+    remaining_key_path = components[1] if len(components) > 1 else None
+
+    val: Any = d.get(key, None)
+    if val is not None:
+        if remaining_key_path is not None:
+            return traverse_dict(val, remaining_key_path)
+        return val
+    else:
+        raise KeyError(f"value not found for key: {key}")
